@@ -6,7 +6,7 @@ from copy import deepcopy
 import pytz
 import redis
 
-from .utils import check_types, get_ids_from_untyped_data, check_callable
+from python_redis_orm.utils import check_types, get_ids_from_untyped_data, check_callable
 
 
 ### FIELDS ###
@@ -356,7 +356,7 @@ class RedisRoot:
         ignore_deserialization_errors=True,
         save_consistency=False,
         economy=False,
-        use_keys=False,
+        use_keys=True,
     ):
         connection_pool = check_callable(connection_pool)
         prefix = check_callable(prefix)
@@ -480,10 +480,11 @@ class RedisRoot:
     def deserialize_value(self, raw_value, model_name, field_name):
         value = raw_value
         saved_model = self._get_registered_model_by_name(model_name)
-        if issubclass(saved_model, RedisModel):
-            saved_field_instance = self._get_field_instance_by_name(field_name, saved_model)
-            if issubclass(saved_field_instance.__class__, RedisField):
-                value = self._deserialize_value_by_field_instance(raw_value, saved_field_instance)
+        if type(saved_model) != str:
+            if issubclass(saved_model, RedisModel):
+                saved_field_instance = self._get_field_instance_by_name(field_name, saved_model)
+                if issubclass(saved_field_instance.__class__, RedisField):
+                    value = self._deserialize_value_by_field_instance(raw_value, saved_field_instance)
         return value
     
     def _return_with_format(self, instances, return_dict=False):
