@@ -1,7 +1,9 @@
 import random
 from time import sleep
+import asyncio
 
-from python_redis_orm.core import *
+
+# from python_redis_orm.core import *
 
 
 def generate_token(chars_count):
@@ -56,7 +58,7 @@ class ListCheckModel(RedisModel):
 
 def clean_db_after_test(connection_pool, prefix):
     redis_instance = redis.Redis(connection_pool=connection_pool)
-    for key in redis_instance.scan_iter(f'{prefix}:*'):
+    for key in redis_instance.keys(f'{prefix}:*'):
         redis_instance.delete(key)
 
 
@@ -113,7 +115,7 @@ def auto_reg_test(connection_pool, prefix):
     return have_exception
 
 
-def no_redis_instance_test(*args, **kwargs):
+def no_connection_pool_test(*args, **kwargs):
     try:
         redis_root = RedisRoot(
             ignore_deserialization_errors=True
@@ -125,7 +127,13 @@ def no_redis_instance_test(*args, **kwargs):
         task_challenge_1.save()
         task_challenges = redis_root.get(TaskChallenge)
         have_exception = False
-        clean_db_after_test(redis_root.redis_instance, redis_root.prefix)
+        connection_pool = redis.ConnectionPool(
+            host='localhost',
+            port=6379,
+            db=0,
+            decode_responses=True
+        )
+        clean_db_after_test(connection_pool, redis_root.prefix)
     except BaseException as ex:
         have_exception = True
     return have_exception
@@ -366,7 +374,8 @@ def economy_test(connection_pool, prefix):
             economy=True
         )
         started_in_economy = datetime.datetime.now()
-        for i in range(10):
+        tests_count = 100
+        for i in range(tests_count):
             task_challenge_1 = TaskChallenge(
                 redis_root=redis_root,
                 status='in_work',
@@ -383,7 +392,7 @@ def economy_test(connection_pool, prefix):
             economy=False
         )
         started_in_no_economy = datetime.datetime.now()
-        for i in range(10):
+        for i in range(tests_count):
             task_challenge_1 = TaskChallenge(
                 redis_root=redis_root,
                 status='in_work',
@@ -404,6 +413,55 @@ def economy_test(connection_pool, prefix):
     return have_exception
 
 
+def use_keys_test(connection_pool, prefix):
+    have_exception = True
+    try:
+        
+        redis_root = RedisRoot(
+            prefix=prefix,
+            connection_pool=connection_pool,
+            ignore_deserialization_errors=True,
+            use_keys=True
+        )
+        started_in_keys = datetime.datetime.now()
+        tests_count = 100
+        for i in range(tests_count):
+            task_challenge_1 = TaskChallenge(
+                redis_root=redis_root,
+                status='in_work',
+            ).save()
+            redis_root.update(TaskChallenge, task_challenge_1, account_checks_count=1)
+        ended_in_keys = datetime.datetime.now()
+        keys_time = (ended_in_keys - started_in_keys).total_seconds()
+        clean_db_after_test(connection_pool, prefix)
+        
+        redis_root = RedisRoot(
+            prefix=prefix,
+            connection_pool=connection_pool,
+            ignore_deserialization_errors=True,
+            use_keys=False
+        )
+        started_in_no_keys = datetime.datetime.now()
+        for i in range(tests_count):
+            task_challenge_1 = TaskChallenge(
+                redis_root=redis_root,
+                status='in_work',
+            ).save()
+            redis_root.update(TaskChallenge, task_challenge_1, account_checks_count=1)
+        ended_in_no_keys = datetime.datetime.now()
+        no_keys_time = (ended_in_no_keys - started_in_no_keys).total_seconds()
+        clean_db_after_test(connection_pool, prefix)
+        keys_percent = round((no_keys_time / keys_time - 1) * 100, 2)
+        keys_symbol = ('+' if keys_percent > 0 else '')
+        print(f'Keys usage gives {keys_symbol}{keys_percent}% efficiency')
+        have_exception = False
+    except BaseException as ex:
+        print(ex)
+    
+    clean_db_after_test(connection_pool, prefix)
+    return have_exception
+
+
 def dict_test(connection_pool, prefix):
     redis_root = RedisRoot(
         prefix=prefix,
@@ -616,7 +674,7 @@ def run_tests():
     tests = [
         basic_test,
         auto_reg_test,
-        no_redis_instance_test,
+        no_connection_pool_test,
         choices_test,
         order_test,
         filter_test,
@@ -627,6 +685,7 @@ def run_tests():
         save_consistency_test,
         meta_ttl_test,
         economy_test,
+        use_keys_test,
         list_test,
         dict_test,
         async_test,
